<?php
declare(strict_types=1);
/**
 * @copyright see LICENSE
 */

namespace Mwltr\FilesystemFileDriver\Helper;

class RelativePathHelper
{
    public function getRelativePath(string $from, string $to): string
    {
        // some compatibility fixes for Windows paths
        $from = is_dir($from) ? rtrim($from, '\/') . '/' : $from;
        $to = is_dir($to) ? rtrim($to, '\/') . '/' : $to;
        $from = str_replace('\\', '/', $from);
        $to = str_replace('\\', '/', $to);

        $fromParts = explode('/', $from);
        $toParts = explode('/', $to);
        $relPath = $toParts;

        foreach ($fromParts as $depth => $dir) {
            // find first non-matching dir
            if ($dir === $toParts[$depth]) {
                // ignore this directory
                array_shift($relPath);
            } else {
                // get number of remaining dirs to $from
                $remaining = \count($fromParts) - $depth;
                if ($remaining > 1) {
                    // add traversals up to first matching dir
                    $padLength = (count($relPath) + $remaining - 1) * -1;
                    $relPath = array_pad($relPath, $padLength, '..');
                    break;
                }

                $relPath[0] = './' . $relPath[0];
            }
        }

        return implode('/', $relPath);
    }
}
